@@ -49,7 +49,7 @@ def get_grid_data(latitude, longitude):
     if (grid_response):
         grid_json_obj = json.loads(grid_response.content)
         grid_properties =  grid_json_obj['properties']
-        forcast_hourly_url = grid_properties['forecastHourly'],
+        forcast_hourly_url = grid_properties['forecastHourly']
         local_timezone_name = grid_properties['timeZone']
 
     return forcast_hourly_url, local_timezone_name
